@@ -14,6 +14,7 @@
 
 from oslo_config import cfg
 from oslo_middleware import request_id as oslo_request_id
+from oslo_serialization import jsonutils
 
 from murano.common.i18n import _
 from murano.common import wsgi
@@ -43,13 +44,16 @@ class ContextMiddleware(wsgi.Middleware):
         roles = [r.strip() for r in req.headers.get('X-Roles').split(',')]
         kwargs = {
             'user': req.headers.get('X-User-Id'),
-            'tenant': req.headers.get('X-Tenant-Id'),
+            'project_id': req.headers.get('X-Tenant-Id'),
             'auth_token': req.headers.get('X-Auth-Token'),
             'session': req.headers.get('X-Configuration-Session'),
             'is_admin': CONF.admin_role in roles,
             'request_id': req.environ.get(oslo_request_id.ENV_REQUEST_ID),
             'roles': roles
         }
+        sc_header = req.headers.get('X-Service-Catalog')
+        if sc_header:
+            kwargs['service_catalog'] = jsonutils.loads(sc_header)
         req.context = murano.context.RequestContext(**kwargs)
 
     @classmethod
