@@ -16,7 +16,7 @@ import inspect
 import os.path
 
 import eventlet
-import six
+from oslo_config import cfg
 from yaql.language import expressions as yaql_expressions
 from yaql.language import specs
 from yaql.language import utils
@@ -28,6 +28,7 @@ from murano.dsl import dsl_types
 from murano.dsl import helpers
 
 
+CONF = cfg.CONF
 NO_VALUE = utils.create_marker('NO_VALUE')
 
 
@@ -59,7 +60,7 @@ class MuranoObjectParameter(yaqltypes.PythonType):
             return False
         if self.murano_class:
             murano_class = self.murano_class
-            if isinstance(murano_class, six.string_types):
+            if isinstance(murano_class, str):
                 return helpers.is_instance_of(
                     value, murano_class,
                     self.version_spec or helpers.get_type(context))
@@ -108,14 +109,13 @@ class MuranoTypeParameter(yaqltypes.PythonType):
         self._resolve_strings = resolve_strings
         self._lazy = lazy
         super(MuranoTypeParameter, self).__init__(
-            (dsl_types.MuranoTypeReference,
-             six.string_types), nullable)
+            (dsl_types.MuranoTypeReference, str), nullable)
 
     def check(self, value, context, *args, **kwargs):
         if not super(MuranoTypeParameter, self).check(
                 value, context, *args, **kwargs):
             return False
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             if not self._resolve_strings:
                 return False
             value = helpers.get_class(value, context).get_reference()
@@ -136,7 +136,7 @@ class MuranoTypeParameter(yaqltypes.PythonType):
                 value2 = value2(utils.NO_VALUE, ctx, engine)
             value2 = super(MuranoTypeParameter, self).convert(
                 value2, sender, ctx, function_spec, engine)
-            if isinstance(value2, six.string_types):
+            if isinstance(value2, str):
                 value2 = helpers.get_class(value2, ctx).get_reference()
             if self._base_type and not self._base_type.is_compatible(value):
                 raise ValueError('Value must be subtype of {0}'.format(
@@ -213,7 +213,7 @@ class MuranoObjectInterface(dsl_types.MuranoObjectInterface):
         return MuranoObjectInterface.create(owner)
 
     def find_owner(self, type, optional=False):
-        if isinstance(type, six.string_types):
+        if isinstance(type, str):
             type = helpers.get_class(type)
         elif isinstance(type, dsl_types.MuranoTypeReference):
             type = type.type
@@ -349,7 +349,9 @@ def to_mutable(obj, yaql_engine=None):
         else:
             return utils.convert_output_data(value, limit_func, engine, rec)
 
-    limiter = lambda it: utils.limit_iterable(it, constants.ITERATORS_LIMIT)
+    def limiter(it):
+        return utils.limit_iterable(it, CONF.murano.dsl_iterators_limit)
+
     return converter(obj, limiter, yaql_engine, converter)
 
 
@@ -381,3 +383,9 @@ def spawn(func, *args, **kwargs):
                 return func(*args, **kwargs)
 
     return eventlet.spawn(wrapper)
+
+
+def new(properties, owner=None, type=None):
+    context = helpers.get_context()
+    return helpers.get_object_store().load(
+        properties, owner, type or get_this(context).type, context=context)
