@@ -12,9 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-
-import six
-
 from murano.dsl import constants
 from murano.dsl import dsl_exception
 from murano.dsl import exceptions
@@ -140,7 +137,7 @@ class WhileDoMacro(expressions.DslExpression):
 
 class ForMacro(expressions.DslExpression):
     def __init__(self, For, In, Do):
-        if not isinstance(For, six.string_types):
+        if not isinstance(For, str):
             raise exceptions.DslSyntaxError(
                 'For value must be of string type')
         self._code = CodeBlock(Do)
@@ -189,7 +186,7 @@ class MatchMacro(expressions.DslExpression):
 
     def execute(self, context):
         match_value = helpers.evaluate(self._value, context)
-        for key, value in six.iteritems(self._switch):
+        for key, value in self._switch.items():
             if key == match_value:
                 CodeBlock(value).execute(context)
                 return
@@ -207,7 +204,7 @@ class SwitchMacro(expressions.DslExpression):
 
     def execute(self, context):
         matched = False
-        for key, value in six.iteritems(self._switch):
+        for key, value in self._switch.items():
             if helpers.evaluate(key, context):
                 matched = True
                 CodeBlock(value).execute(context)
