@@ -18,7 +18,6 @@ import copy
 import weakref
 
 import semantic_version
-import six
 from yaql.language import utils
 
 from murano.dsl import constants
@@ -263,7 +262,7 @@ class MuranoClass(dsl_types.MuranoClass, MuranoType, dslmeta.MetaProvider):
     def find_methods(self, predicate):
         result = list(filter(predicate, self.methods.values()))
         for c in self.ancestors():
-            for method in six.itervalues(c.methods):
+            for method in c.methods.values():
                 if predicate(method) and method not in result:
                     result.append(method)
         return result
@@ -280,9 +279,9 @@ class MuranoClass(dsl_types.MuranoClass, MuranoType, dslmeta.MetaProvider):
         for name in self.all_method_names:
             try:
                 yield self.find_single_method(name)
-            except exceptions.AmbiguousMethodName as e:
+            except exceptions.AmbiguousMethodName:
                 def func(*args, **kwargs):
-                    raise e
+                    raise
                 yield murano_method.MuranoMethod(
                     self, name, func, ephemeral=True)
 
@@ -345,7 +344,7 @@ class MuranoClass(dsl_types.MuranoClass, MuranoType, dslmeta.MetaProvider):
                     (parent.package, requirement))
 
         package_bindings = {}
-        for versions in six.itervalues(aggregation):
+        for versions in aggregation.values():
             mappings = self._remap_package(versions)
             package_bindings.update(mappings)
 
@@ -504,7 +503,7 @@ def _create_class(cls, name, ns_resolver, data, package, *args, **kwargs):
         data.get('Import'), *args, **kwargs)
 
     properties = data.get('Properties') or {}
-    for property_name, property_spec in six.iteritems(properties):
+    for property_name, property_spec in properties.items():
         spec = murano_property.MuranoProperty(
             type_obj, property_name, property_spec)
         type_obj.add_property(spec)
@@ -516,7 +515,7 @@ def _create_class(cls, name, ns_resolver, data, package, *args, **kwargs):
         'destroy': '.destroy'
     }
 
-    for method_name, payload in six.iteritems(methods):
+    for method_name, payload in methods.items():
         type_obj.add_method(
             method_mappings.get(method_name, method_name), payload)
 
@@ -529,7 +528,7 @@ def _create_meta_class(cls, name, ns_resolver, data, package, *args, **kwargs):
         raise ValueError(u'Invalid MetaClass Cardinality "{}"'.format(
             cardinality))
     applies_to = data.get('Applies', dsl_types.MetaTargets.All)
-    if isinstance(applies_to, six.string_types):
+    if isinstance(applies_to, str):
         applies_to = [applies_to]
     if isinstance(applies_to, list):
         applies_to = set(applies_to)
@@ -564,7 +563,7 @@ def weigh_type_hierarchy(cls):
 
     result = {}
     for c, w in helpers.traverse(
-            [(cls, 0)], lambda t: six.moves.map(
+            [(cls, 0)], lambda t: map(
                 lambda p: (p, t[1] + 1), t[0].parents)):
         result.setdefault(c.name, w)
     return result
