@@ -14,44 +14,59 @@
 
 import weakref
 
+from murano.dsl.contracts import contracts
 from murano.dsl import dsl_types
-from murano.dsl import exceptions
 from murano.dsl import helpers
-from murano.dsl import type_scheme
 
 
 class Spec(object):
     def __init__(self, declaration, container_type):
         self._container_type = weakref.ref(container_type)
-        self._contract = type_scheme.TypeScheme(declaration['Contract'])
-        self._usage = declaration.get('Usage') or dsl_types.PropertyUsages.In
-        self._default = declaration.get('Default')
+        self._contract = contracts.Contract(
+            declaration['Contract'], container_type)
         self._has_default = 'Default' in declaration
-        if self._usage not in dsl_types.PropertyUsages.All:
-            raise exceptions.DslSyntaxError(
-                'Unknown type {0}. Must be one of ({1})'.format(
-                    self._usage, ', '.join(dsl_types.PropertyUsages.All)))
+        self._default = declaration.get('Default')
 
-    def transform(self, value, this, owner, context, default=None):
+    def _get_this_context(self, this):
+        executor = helpers.get_executor()
+        if isinstance(this, dsl_types.MuranoType):
+            return executor.create_object_context(this)
+        return executor.create_object_context(
+            this.cast(self._container_type()))
+
+    def transform(self, value, this, owner, context, default=None,
+                  finalize=True):
         if default is None:
             default = self.default
-        executor = helpers.get_executor(context)
         if isinstance(this, dsl_types.MuranoTypeReference):
             this = this.type
         if isinstance(this, dsl_types.MuranoType):
             return self._contract.transform(
-                value, executor.create_object_context(this),
-                None, None, default, helpers.get_type(context))
+                value, self._get_this_context(this),
+                None, None, default, helpers.get_type(context),
+                finalize=finalize)
         else:
             return self._contract.transform(
-                value, executor.create_object_context(
-                    this.cast(self._container_type())),
-                this, owner, default, helpers.get_type(context))
+                value, self._get_this_context(this),
+                this, owner, default, helpers.get_type(context),
+                finalize=finalize)
 
-    def validate(self, value, context, default=None):
+    def validate(self, value, this, context, default=None):
         if default is None:
             default = self.default
-        return self._contract.validate(value, context, default)
+        return self._contract.validate(
+            value, self._get_this_context(this), default,
+            helpers.get_type(context))
+
+    def check_type(self, value, context, default=None):
+        if default is None:
+            default = self.default
+        return self._contract.check_type(
+            value, context, default, helpers.get_type(context))
+
+    def finalize(self, value, this, context):
+        return self._contract.finalize(
+            value, self._get_this_context(this), helpers.get_type(context))
 
     @property
     def default(self):
@@ -66,5 +81,5 @@ class Spec(object):
         return self._has_default
 
     @property
-    def usage(self):
-        return self._usage
+    def declaring_type(self):
+        return self._container_type()
