@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import collections
+from collections import abc
 import random
 import re
 import string
@@ -21,8 +21,9 @@ import time
 
 import jsonpatch
 import jsonpointer
+from oslo_config import cfg as oslo_cfg
+from oslo_log import log as logging
 from oslo_serialization import base64
-import six
 from yaql.language import specs
 from yaql.language import utils
 from yaql.language import yaqltypes
@@ -33,6 +34,12 @@ from murano.dsl import dsl
 from murano.dsl import helpers
 from murano.dsl import yaql_integration
 
+from castellan.common import exception as castellan_exception
+from castellan.common import utils as castellan_utils
+from castellan import key_manager
+from castellan import options
+
+LOG = logging.getLogger(__name__)
 
 _random_string_counter = None
 
@@ -56,21 +63,21 @@ def pselect(collection, composer):
     return helpers.parallel_select(collection, composer)
 
 
-@specs.parameter('mappings', collections.Mapping)
+@specs.parameter('mappings', abc.Mapping)
 @specs.extension_method
 def bind(obj, mappings):
-    if isinstance(obj, six.string_types) and obj.startswith('$'):
+    if isinstance(obj, str) and obj.startswith('$'):
         value = _convert_macro_parameter(obj[1:], mappings)
         if value is not None:
             return value
     elif utils.is_sequence(obj):
         return [bind(t, mappings) for t in obj]
-    elif isinstance(obj, collections.Mapping):
+    elif isinstance(obj, abc.Mapping):
         result = {}
-        for key, value in six.iteritems(obj):
+        for key, value in obj.items():
             result[bind(key, mappings)] = bind(value, mappings)
         return result
-    elif isinstance(obj, six.string_types) and obj.startswith('$'):
+    elif isinstance(obj, str) and obj.startswith('$'):
         value = _convert_macro_parameter(obj[1:], mappings)
         if value is not None:
             return value
@@ -82,7 +89,7 @@ def _convert_macro_parameter(macro, mappings):
 
     def replace(match):
         replaced[0] = True
-        return six.text_type(mappings.get(match.group(1)))
+        return str(mappings.get(match.group(1)))
 
     result = re.sub('{(\\w+?)}', replace, macro)
     if replaced[0]:
@@ -203,6 +210,27 @@ def logger(context, logger_name):
     return log
 
 
+@specs.parameter('value', yaqltypes.String())
+@specs.extension_method
+def decrypt_data(value):
+    options.set_defaults(oslo_cfg.CONF,
+                         barbican_endpoint_type='internal')
+    manager = key_manager.API()
+    try:
+        context = castellan_utils.credential_factory(conf=cfg.CONF)
+    except castellan_exception.AuthTypeInvalidError as e:
+        LOG.exception(e)
+        LOG.error("Castellan must be correctly configured in order to use "
+                  "decryptData()")
+        raise
+    try:
+        data = manager.get(context, value).get_encoded()
+    except castellan_exception.KeyManagerError as e:
+        LOG.exception(e)
+        raise
+    return data
+
+
 @helpers.memoize
 def get_context(runtime_version):
     context = yaql_integration.create_empty_context()
@@ -213,6 +241,7 @@ def get_context(runtime_version):
     context.register_function(random_name)
     context.register_function(patch_)
     context.register_function(logger)
+    context.register_function(decrypt_data, 'decryptData')
 
     if runtime_version <= constants.RUNTIME_VERSION_1_1:
         context.register_function(substr)
