@@ -14,12 +14,13 @@
 # limitations under the License.
 
 import logging
+from unittest import mock
 
 import fixtures
-import mock
+from oslo_config import cfg
 from oslo_utils import timeutils
 import routes
-from six.moves import urllib
+import urllib
 import webob
 
 from murano.api.v1 import request_statistics
@@ -115,6 +116,7 @@ class ControllerTest(object):
         # cfg.CONF.set_default('host', 'server.test')
         self.api_version = '1.0'
         self.tenant = 'test_tenant'
+        self.user = 'test_user'
         self.mock_policy_check = None
         self.mapper = routes.Mapper()
         self.api = router.API(self.mapper)
@@ -125,7 +127,7 @@ class ControllerTest(object):
         super(ControllerTest, self).setUp()
 
         self.is_admin = False
-
+        cfg.CONF(args=[], project='murano')
         policy.init(use_conf=False)
         real_policy_check = policy.check
 
@@ -232,6 +234,14 @@ class ControllerTest(object):
         return self._data_request(path, data, content_type, method='PUT',
                                   params=params, user=user, tenant=tenant)
 
+    def _patch(self, path, data,
+               content_type='application/murano-packages-json-patch',
+               params=None, user=DEFAULT_USER, tenant=DEFAULT_TENANT):
+        if params is None:
+            params = {}
+        return self._data_request(path, data, content_type, method='PATCH',
+                                  params=params, user=user, tenant=tenant)
+
     def _set_policy_rules(self, rules):
         policy.set_rules(rules, default_rule='default')
 
